import axios, {
    AxiosResponse,
    AxiosError
} from "../../node_modules/axios/index"


interface IToDo {
    "userId": number,
    "id": number,
    "title": string,
    "completed": boolean
}

let baseUrl = 'http://jsonplaceholder.typicode.com/todos';

new Vue({
    // TypeScript compiler complains about Vue because the CDN link to Vue is in the html file.
    // Before the application runs this TypeScript file will be compiled into bundle.js
    // which is included at the bottom of the html file.
    el: "#app",
    data: {
        toDos: [],
        singleToDo: null,
        toDoId: 0,
        formData: { userId: undefined, title: "", completed: false },
        addMessage: "",
        addStatus: ""
    },
    methods: {
        /* Benytter Promise
        getAllToDos() {           
            axios.get<IToDo[]>(baseUrl)
              .then((response: AxiosResponse<IToDo[]>) => {
                this.toDos = response.data;
            })
              .catch((error: AxiosError) => {
                //this.message = error.message
                alert(error.message) // https://www.w3schools.com/js/js_popup.asp
            });   
          },
*/
        //ES2018 version med async/await og opdateret tsconfig.json fil
        async getAllToDosAsync() {
            try { return axios.get<IToDo[]>(baseUrl) }
            catch (error: AxiosError) {
                this.message = error.message;
                alert(error.message)
            }
        },

        async getAllToDos() {
            let response = await this.getAllToDosAsync();
            this.toDos = response.data;
        },

        getToDoById(id: number) {
            let url: string = baseUrl + "/" + id
            axios.get<IToDo>(url)
                .then((response: AxiosResponse<IToDo>) => {
                    this.singleToDo = response.data
                })
                .catch((error: AxiosError) => {
                    this.message = error.message
                    alert(error.message) // https://www.w3schools.com/js/js_popup.asp
                })
        },

        /*
        addToDo() {
            console.log("POST");
            console.log(this.formData);
            axios.post<IToDo>(baseUrl,{
                userId: '1',
                title: "test",
                completed: false
              })
                .then((response: AxiosResponse) => {
                    let message: string = "response " + response.status + " " + response.statusText
                    this.addMessage = message;
                    console.log("message" + message);
                })
                .catch((error: AxiosError) => {
                    this.addMessage = error.message
                    console.log("message" + error.message);
                    alert(error.message)
                })
        },
        */
        async addToDoAsync() {
            try {
                return axios.post<IToDo>(baseUrl, this.formData)
            }
            catch (error: AxiosError) {
                this.addMessage = error.message
                console.log("message" + error.message);
                alert(error.message)
            }
        },

        async addToDo(){
          let response = await this.addToDoAsync();
          this.addStatus = "Status: " + response.status + ' ' + response.statusText;
          this.addMessage = "Response data: " + JSON.stringify(response.data);  
        },
        clearOutput() {
            this.addMessage = "";
            this.addStatus = "";
            this.formData.title="";
            this.formData.userId=undefined;
        },
        clearList() {
            this.toDos = [];
        },
        clearSingleToDo() {
            this.singleToDo = null;
            this.toDoId = 0;
        }

    }
})


